# -*- coding: utf-8 -*-
#
# File: googlecoop.py
#
# Copyright (c) 2007 by []
# Generator: ArchGenXML Version 1.6.0-beta-svn
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Christian Ledermann <unknown>"""
__docformat__ = 'plaintext'


# Product configuration.
#
# The contents of this module will be imported into __init__.py, the
# workflow configuration and every content type module.
#
# If you wish to perform custom configuration, you may put a file
# AppConfig.py in your product's root directory. The items in there
# will be included (by importing) in this file if found.

from Products.CMFCore.permissions import setDefaultRoles

##code-section config-head #fill in your manual code here
from Products.Archetypes.public import DisplayList
##/code-section config-head


PROJECTNAME = "googlecoop"

# Permissions
DEFAULT_ADD_CONTENT_PERMISSION = "Manage Portal"
setDefaultRoles(DEFAULT_ADD_CONTENT_PERMISSION, ('Manager', 'Owner'))

product_globals = globals()

# Dependencies of Products to be installed by quick-installer
# override in custom configuration
DEPENDENCIES = []

# Dependend products - not quick-installed - used in testcase
# override in custom configuration
PRODUCT_DEPENDENCIES = []

# You can overwrite these two in an AppConfig.py:
# STYLESHEETS = [
#     {'id': 'my_global_stylesheet.css'},
#     {'id': 'my_contenttype.css',
#      'expression': 'python:object.getTypeInfo().getId() == "MyType"'}]
# You can do the same with JAVASCRIPTS.
STYLESHEETS = []
JAVASCRIPTS = []

##code-section config-bottom #fill in your manual code here
ADPLACEMENT = DisplayList((
	('FORID:9', 'Right'),
	('FORID:10', 'Top and Right'),
	('FORID:11', 'Top and Bottom'),
	))

ADDSTATUS = DisplayList((
        ('false', 'Show ads on results pages'),
        ('true', 'Do not show ads on results pages (for non-profits, universities, and government agencies only)'),
        ))
##/code-section config-bottom


# Load custom configuration not managed by archgenxml
try:
    from Products.googlecoop.AppConfig import *
except ImportError:
    pass
